@@ -11,6 +11,7 @@ import itertools
 import numpy as np
 from scipy import stats, special
 import sobol
+import warnings
 
 class Data:
     """
@@ -409,7 +410,7 @@ class RandomExperiment(Data):
             for index, sample in enumerate(eval_dict):
                 res.append(eval_func((index + len(self.x_prev), sample), params=params))
                 with open(self.my_data.filename_samples, 'a+') as file:
-                    line = list(samples[index]) + res[-1]
+                    line = list(samples[index]) + list(res[-1])
                     for j in line:
                         file.write('%25f ' % j)
                     file.write('\n')
@@ -813,8 +814,8 @@ class PCE(RandomExperiment):
             self.loo += 1.0 / float(size) * deltai**2. / (np.var(y_res))
 
         if self.loo > 1.:
-            raise Warning("""The LOO error is higher than 1.
-                                Check the UQ characterization and results.""")
+            warnings.warn("The LOO error is higher than 1. "
+                          "Check the UQ characterization and results.")
 
     ##########################
     # result printing module #
